@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 
 def run(app):
-    import sys, os
+    import sys
     from werkzeug.serving import run_simple
 
     host = '0.0.0.0'
     try:
-        port = sys.argv[1]
+        port = int(sys.argv[1])
     except:
-        port = '8080'
+        port = 8080
     run_simple(host, port, app, threaded=True, use_debugger=True)
